@@ -25,17 +25,26 @@ class AFPEntitiesParameters(ProcessorParameters):
     <li>**default** deduplicate and if overlap keeps only the longest match<br />
     <li>**linker** to retain only known entities<br />
     <li>**unknown** to retain all but prepending the `unknown_prefix` to the label of unknown entities<br />""",
+        extra="advanced,internal",
     )
     kill_label: Optional[str] = Field("kill", description="Label name of the kill list")
-    white_label: Optional[str] = Field("white", description="Label name of the white list")
+    white_label: Optional[str] = Field(
+        "white", description="Label name of the white list"
+    )
     eurovoc_label: Optional[str] = Field(
         "eurovoc", description="Label name of the Eurovoc thesaurus"
     )
-    wikidata_label: Optional[str] = Field("wikidata", description="Label name of Wikidata entities")
+    wikidata_label: Optional[str] = Field(
+        "wikidata", description="Label name of Wikidata entities"
+    )
     as_altText: str = Field(
         "fingerprint",
         description="""If defined generate the fingerprint as an alternative text of the input document.""",
     )
+    remove_suspicious: bool = Field(
+        True,
+        description="Remove suspicious annotations extracted by the model (numbers, percentages, phrases without uppercase words)",
+    )
 
 
 class AFPEntitiesProcessor(ProcessorBase):
@@ -64,8 +73,14 @@ class AFPEntitiesProcessor(ProcessorBase):
                         )
                         document.altTexts = altTexts
                     # 2. Consolidate & links against KB and Wikidata
-                    conso_anns = consolidate_and_link(ann_groups, params.kill_label, params.white_label,
-                                                      params.wikidata_label, params.eurovoc_label)
+                    conso_anns = consolidate_and_link(
+                        ann_groups,
+                        params.kill_label,
+                        params.white_label,
+                        params.wikidata_label,
+                        params.eurovoc_label,
+                        params.remove_suspicious,
+                    )
                     document.annotations = conso_anns
         return documents
 
@@ -116,17 +131,34 @@ def compute_fingerprint(ann_groups):
 
 def mark_whitelisted(document, white_label):
     for a in document.annotations:
-        if a.labelName == white_label:  # Consider whitelisted terms as entities coming from the model
+        if (
+            a.labelName == white_label
+        ):  # Consider whitelisted terms as entities coming from the model
             a.terms = None
 
 
-def consolidate_and_link(ann_groups, kill_label, white_label, wikidata_label, eurovoc_label):
+def consolidate_and_link(
+    ann_groups,
+    kill_label,
+    white_label,
+    wikidata_label,
+    eurovoc_label,
+    remove_suspicious,
+):
     conso_anns = []
-    kb_names = [item for item in ann_groups.keys() if item not in ["", kill_label, white_label, wikidata_label, eurovoc_label]]
+    kb_names = [
+        item
+        for item in ann_groups.keys()
+        if item not in ["", kill_label, white_label, wikidata_label, eurovoc_label]
+    ]
     for model_r in ann_groups[""].ranges():
         model_ann = model_r.value
         gname = model_ann.labelName
 
+        if remove_suspicious and is_suspicious(model_ann):
+            logger.warning("Kill suspicious annotation")
+            logger.warning(f"=> {model_ann}")
+            continue
         kill_r = annotation_in_group(model_ann, ann_groups, [kill_label])
         perfect, kill_match = one_match(model_ann, kill_r)
         if perfect and kill_match:
@@ -224,22 +256,32 @@ def one_match(a: Annotation, matches: RangeMap):
     return perfect, match
 
 
+def is_suspicious(a: Annotation):
+    suspicious = False
+    if a.text:
+        words = a.text.split()
+        has_upper = any([w[0].isupper() for w in words])
+        suspicious = not has_upper
+    return suspicious
+
+
 # noqa: W503
 def annotation_in_group(
     a: Annotation, ann_groups: Dict[str, RangeMap], gnames: List[str] = None
 ):
-    gnames = gnames or [a.labelName]
+    if a.labelName in gnames:
+        gnames = [a.labelName]
     for gname in gnames:
         if (
-                gname in ann_groups
-                and a.start in ann_groups[gname]
-                or a.end in ann_groups[gname]
+            gname in ann_groups
+            and a.start in ann_groups[gname]
+            or a.end in ann_groups[gname]
         ):
-            return ann_groups[gname][a.start: a.end]
+            return ann_groups[gname][a.start : a.end]
     return None
 
 
-# noqa: W503
+# noqa
 def validate_wiki_type(w: Annotation, gname: str):
     match = None
     if w.terms and len(w.terms) and w.terms[0].properties:
@@ -285,6 +327,8 @@ def validate_wiki_type(w: Annotation, gname: str):
                                 "Q1530022",
                                 "Q20746389",
                                 "Q48204",
+                                "Q207320",
+                                "Q7278"
                             ]
                         ),
                         fingerprint,
